{ config, pkgs, ...}: {
  imports = [
    ./hardware-configuration.nix
    ../../common/variables.nix
    ../../common/system.nix
    ../../common/grub.nix
    ../../common/user.nix
    ../../common/tailscale.nix
    ../../common/secrets.nix
  ];

  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nix.settings.sandbox = "relaxed";

  nix.settings.substituters = [
    "https://cache.nixos.org/"
  ];

  nix.settings.trusted-users = [ "rose" ];
  nix.settings.trusted-public-keys = [
    "hemera.tempest.local:Tb4edCxlB4YNGJNnVYrpNkTmG82tCChVNXdes33y2kY="
  ];

  home-manager.useGlobalPkgs = true;
  home-manager.useUserPackages = true;

  networking.extraHosts = ''
    100.104.209.75 hemera hemera.tempest.local
    100.64.81.74 necronomicon necronomicon.tempest.local
    100.67.153.61 melete melete.tempest.local
  '';

  ashe.system.hostname = "nyx";
  ashe.system.disk = "/dev/vda";

  ashe.user.username = "rose";
  ashe.user.description = "Ashelyn Rose";
  ashe.user.packages = with pkgs; [
    neofetch
    bat
    lazygit
    tmux
    psmisc
  ];

  networking.enableIPv6 = false;
  networking.firewall.allowedTCPPorts = [ 22 80 443 ];
  networking.interfaces.ens3 = {
    ipv4.addresses = [ {
      address = "104.168.211.198";
      prefixLength = 16;
    } {
      address = "104.168.143.74";
      prefixLength = 16;
    }];
  };

  networking.defaultGateway = "104.168.218.1";
  networking.nameservers = [ "8.8.8.8" ];

  networking.wireless.enable = false;
  networking.networkmanager.enable = false;

  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.11";
}
